#' EFPREDICT Prediction of ecosystem processes and functions for intertidal communities
#' 
#' The EFPREDICT package calculates a range of ecosystem processes and functions for intertidal animal and algal communities. This package is suitable to apply to artifical coastal structures and natural intertidal habitats, such as rocky reefs. It allows the predictions for oxygen fluxes (respiration, primary productivity), nutrient fluxes (uptake/excretion of ammonium and nitrate), filtration efficiency (clearance rate), carbon flux, biomass
#'
#' @Import vegan, readxl, openxlsx
#' #' 
#' @export



EFPREDICT<-function(input,output){
  load("EFTOOLD2.RData")
  PRED<-readxl::read_excel(input, sheet = "Output")
  ARTADD1<- data.frame("REF","Other_Crab","Animal","Arthropoda","Arthropoda",NA,NA,NA,NA,0,7.754403461,0,0,"0","1","0","Crab",10,10,10,30,500,NA,"1","0","0","0","0","0","0","1","0",0,0,0,0,0,0,0,"NOTa")        ##ADD DUMMY VARIABLE, WITH 0 COMMUNITY MASS IN CASE FN.GR IS EMPTY
  ASCADD1<- data.frame("REF","Ciona _intestinalis","Animal","Chordata","Ascidea",NA,NA,NA,NA,0,0.07704,0,0,"0","0","0","0",10,10,10,30,500,NA,"1","0","0","0","0","0","0","1","1",0,0,0,0,0,0,0,"NOTa")           ##ADD DUMMY VARIABLE, WITH 0 COMMUNITY MASS IN CASE FN.GR IS EMPTY
  BRYADD1<- data.frame("REF","Other_Bryozoan","Animal","Bryozoa","Bryozoa",NA,NA,NA,NA,0,0.00000328889,0,0,"0","0","0","0",10,10,10,30,500,NA,"1","0","0","0","0","0","0","1","1",0,0,0,0,0,0,0,"NOTa")           ##ADD DUMMY VARIABLE, WITH 0 COMMUNITY MASS IN CASE FN.GR IS EMPTY
  BIVADD1<- data.frame("REF","Other_Solitary_Bivalves","Animal","Mollusca","Bivalvia",NA,NA,NA,NA,0,0.0049,0,0,"0","1","0","0",10,10,10,30,500,NA,"1","0","0","0","0","0","0","1","1",0,0,0,0,0,0,0,"NOTa")       ##ADD DUMMY VARIABLE, WITH 0 COMMUNITY MASS IN CASE FN.GR IS EMPTY
  CIRADD1<- data.frame("REF","Other_Barnacle","Animal","Arthropoda","Cirripedia",NA,NA,NA,NA,0,0.008204002,0,0,"0","1","0","0",10,10,10,30,500,NA,"1","0","0","0","0","0","0","1","1",0,0,0,0,0,0,0,"NOTa")       ##ADD DUMMY VARIABLE, WITH 0 COMMUNITY MASS IN CASE FN.GR IS EMPTY
  CNIADD1<- data.frame("REF","Anemonia_viridis","Animal","Cnidaria","Cnidaria",NA,NA,NA,NA,0,2,0,0,"1","0","0","0",10,10,10,30,500,NA,"1","0","0","1","0","0","1","1","1",0,0,0,0,0,0,0,"NOTa")                   ##ADD DUMMY VARIABLE, WITH 0 COMMUNITY MASS IN CASE FN.GR IS EMPTY
  DEMADD1<- data.frame("REF","Other_Sponges","Animal","Porifera","Demospongae",NA,NA,NA,NA,0,0.2,0,0,"0","0","0","0",10,10,10,30,500,NA,"1","0","0","0","0","0","0","0","0",0,0,0,0,0,0,0,"NOTa")                 ##ADD DUMMY VARIABLE, WITH 0 COMMUNITY MASS IN CASE FN.GR IS EMPTY
  ECHADD1<- data.frame("REF","Other_Starfish","Animal","Echinodermata","Echinodermata",NA,NA,NA,NA,0,1.040266667,0,0,"0","0","0","0",10,10,10,30,500,NA,"1","0","0","0","0","0","0","0","0",0,0,0,0,0,0,0,"NOTa") ##ADD DUMMY VARIABLE, WITH 0 COMMUNITY MASS IN CASE FN.GR IS EMPTY
  GASADD1<- data.frame("REF","Patella_vulgata","Animal","Mollusca","Gastropoda",NA,NA,NA,NA,0,0.637005618,0,0,"0","1","0","0",10,10,10,30,500,NA,"1","0","0","0","0","0","0","1","1",0,0,0,0,0,0,0,"NOTa")        ##ADD DUMMY VARIABLE, WITH 0 COMMUNITY MASS IN CASE FN.GR IS EMPTY
  PISADD1<- data.frame("REF","Lipophrys_pholis","Animal","Chordata","Pisces",NA,NA,NA,NA,0,1.388642747,0,0,"0","0","0","0",10,10,10,30,500,NA,"1","0","0","0","0","0","0","1","0",0,0,0,0,0,0,0,"NOTa")           ##ADD DUMMY VARIABLE, WITH 0 COMMUNITY MASS IN CASE FN.GR IS EMPTY
  POLADD1<- data.frame("REF","Other_Worms","Animal","Annelida","Polychaeta",NA,NA,NA,NA,0,0.184260636,0,0,"0","0","0","Errant",10,10,10,30,500,NA,"1","0","0","0","0","0","1","1","0",0,0,0,0,0,0,0,"NOTa")       ##ADD DUMMY VARIABLE, WITH 0 COMMUNITY MASS IN CASE FN.GR IS EMPTY
  MACADD1<- data.frame("REF","Chorda_filum","Macroalgae","Ochrophyta","Leathery",2,8,"L.FO",1.043,0,0,416.52,4273.99,"1","0","3","0",10,10,10,30,500,"0","0","1","1","0","1","1","0","0","0",0,0,0,0,0,0,0,"NOTa")            ##ADD DUMMY VARIABLE, WITH 0 COMMUNITY MASS IN CASE FN.GR IS EMPTY
  names(ARTADD1)<-c("Ref","Taxa","Type","Phylum","FN.GP","EKMED","EK_HCA","FN.GP2", "Thickness","COMBIOM","BIOM","SAV","STA","Photoautotroph","Calcified","COL","ADDIT","Temperature","Nitrate","Ammonium","Salinity","Light","Surge","IncludeRespA","IncludeRespB","IncludeProdA","IncludeProdB","IncludeNit","IncludeAmmupA","IncludeAmmupB","IncludeAmmex","IncludeClr","DO2RESP","DO2PROD","NO3.UT","NH4.UT","NH4.EXC","CRate", "Structure", "Sample_Name") ##ADD DUMMY VARIABLE NAMES
  names(ASCADD1)<-c("Ref","Taxa","Type","Phylum","FN.GP","EKMED","EK_HCA","FN.GP2", "Thickness","COMBIOM","BIOM","SAV","STA","Photoautotroph","Calcified","COL","ADDIT","Temperature","Nitrate","Ammonium","Salinity","Light","Surge","IncludeRespA","IncludeRespB","IncludeProdA","IncludeProdB","IncludeNit","IncludeAmmupA","IncludeAmmupB","IncludeAmmex","IncludeClr","DO2RESP","DO2PROD","NO3.UT","NH4.UT","NH4.EXC","CRate", "Structure", "Sample_Name") ##ADD DUMMY VARIABLE NAMES
  names(BRYADD1)<-c("Ref","Taxa","Type","Phylum","FN.GP","EKMED","EK_HCA","FN.GP2", "Thickness","COMBIOM","BIOM","SAV","STA","Photoautotroph","Calcified","COL","ADDIT","Temperature","Nitrate","Ammonium","Salinity","Light","Surge","IncludeRespA","IncludeRespB","IncludeProdA","IncludeProdB","IncludeNit","IncludeAmmupA","IncludeAmmupB","IncludeAmmex","IncludeClr","DO2RESP","DO2PROD","NO3.UT","NH4.UT","NH4.EXC","CRate", "Structure", "Sample_Name") ##ADD DUMMY VARIABLE NAMES
  names(BIVADD1)<-c("Ref","Taxa","Type","Phylum","FN.GP","EKMED","EK_HCA","FN.GP2", "Thickness","COMBIOM","BIOM","SAV","STA","Photoautotroph","Calcified","COL","ADDIT","Temperature","Nitrate","Ammonium","Salinity","Light","Surge","IncludeRespA","IncludeRespB","IncludeProdA","IncludeProdB","IncludeNit","IncludeAmmupA","IncludeAmmupB","IncludeAmmex","IncludeClr","DO2RESP","DO2PROD","NO3.UT","NH4.UT","NH4.EXC","CRate", "Structure", "Sample_Name") ##ADD DUMMY VARIABLE NAMES
  names(CNIADD1)<-c("Ref","Taxa","Type","Phylum","FN.GP","EKMED","EK_HCA","FN.GP2", "Thickness","COMBIOM","BIOM","SAV","STA","Photoautotroph","Calcified","COL","ADDIT","Temperature","Nitrate","Ammonium","Salinity","Light","Surge","IncludeRespA","IncludeRespB","IncludeProdA","IncludeProdB","IncludeNit","IncludeAmmupA","IncludeAmmupB","IncludeAmmex","IncludeClr","DO2RESP","DO2PROD","NO3.UT","NH4.UT","NH4.EXC","CRate", "Structure", "Sample_Name") ##ADD DUMMY VARIABLE NAMES
  names(CIRADD1)<-c("Ref","Taxa","Type","Phylum","FN.GP","EKMED","EK_HCA","FN.GP2", "Thickness","COMBIOM","BIOM","SAV","STA","Photoautotroph","Calcified","COL","ADDIT","Temperature","Nitrate","Ammonium","Salinity","Light","Surge","IncludeRespA","IncludeRespB","IncludeProdA","IncludeProdB","IncludeNit","IncludeAmmupA","IncludeAmmupB","IncludeAmmex","IncludeClr","DO2RESP","DO2PROD","NO3.UT","NH4.UT","NH4.EXC","CRate", "Structure", "Sample_Name") ##ADD DUMMY VARIABLE NAMES
  names(DEMADD1)<-c("Ref","Taxa","Type","Phylum","FN.GP","EKMED","EK_HCA","FN.GP2", "Thickness","COMBIOM","BIOM","SAV","STA","Photoautotroph","Calcified","COL","ADDIT","Temperature","Nitrate","Ammonium","Salinity","Light","Surge","IncludeRespA","IncludeRespB","IncludeProdA","IncludeProdB","IncludeNit","IncludeAmmupA","IncludeAmmupB","IncludeAmmex","IncludeClr","DO2RESP","DO2PROD","NO3.UT","NH4.UT","NH4.EXC","CRate", "Structure", "Sample_Name") ##ADD DUMMY VARIABLE NAMES
  names(ECHADD1)<-c("Ref","Taxa","Type","Phylum","FN.GP","EKMED","EK_HCA","FN.GP2", "Thickness","COMBIOM","BIOM","SAV","STA","Photoautotroph","Calcified","COL","ADDIT","Temperature","Nitrate","Ammonium","Salinity","Light","Surge","IncludeRespA","IncludeRespB","IncludeProdA","IncludeProdB","IncludeNit","IncludeAmmupA","IncludeAmmupB","IncludeAmmex","IncludeClr","DO2RESP","DO2PROD","NO3.UT","NH4.UT","NH4.EXC","CRate", "Structure", "Sample_Name") ##ADD DUMMY VARIABLE NAMES
  names(GASADD1)<-c("Ref","Taxa","Type","Phylum","FN.GP","EKMED","EK_HCA","FN.GP2", "Thickness","COMBIOM","BIOM","SAV","STA","Photoautotroph","Calcified","COL","ADDIT","Temperature","Nitrate","Ammonium","Salinity","Light","Surge","IncludeRespA","IncludeRespB","IncludeProdA","IncludeProdB","IncludeNit","IncludeAmmupA","IncludeAmmupB","IncludeAmmex","IncludeClr","DO2RESP","DO2PROD","NO3.UT","NH4.UT","NH4.EXC","CRate", "Structure", "Sample_Name") ##ADD DUMMY VARIABLE NAMES
  names(PISADD1)<-c("Ref","Taxa","Type","Phylum","FN.GP","EKMED","EK_HCA","FN.GP2", "Thickness","COMBIOM","BIOM","SAV","STA","Photoautotroph","Calcified","COL","ADDIT","Temperature","Nitrate","Ammonium","Salinity","Light","Surge","IncludeRespA","IncludeRespB","IncludeProdA","IncludeProdB","IncludeNit","IncludeAmmupA","IncludeAmmupB","IncludeAmmex","IncludeClr","DO2RESP","DO2PROD","NO3.UT","NH4.UT","NH4.EXC","CRate", "Structure", "Sample_Name") ##ADD DUMMY VARIABLE NAMES
  names(POLADD1)<-c("Ref","Taxa","Type","Phylum","FN.GP","EKMED","EK_HCA","FN.GP2", "Thickness","COMBIOM","BIOM","SAV","STA","Photoautotroph","Calcified","COL","ADDIT","Temperature","Nitrate","Ammonium","Salinity","Light","Surge","IncludeRespA","IncludeRespB","IncludeProdA","IncludeProdB","IncludeNit","IncludeAmmupA","IncludeAmmupB","IncludeAmmex","IncludeClr","DO2RESP","DO2PROD","NO3.UT","NH4.UT","NH4.EXC","CRate", "Structure", "Sample_Name") ##ADD DUMMY VARIABLE NAMES
  names(MACADD1)<-c("Ref","Taxa","Type","Phylum","FN.GP","EKMED","EK_HCA","FN.GP2", "Thickness","COMBIOM","BIOM","SAV","STA","Photoautotroph","Calcified","COL","ADDIT","Temperature","Nitrate","Ammonium","Salinity","Light","Surge","IncludeRespA","IncludeRespB","IncludeProdA","IncludeProdB","IncludeNit","IncludeAmmupA","IncludeAmmupB","IncludeAmmex","IncludeClr","DO2RESP","DO2PROD","NO3.UT","NH4.UT","NH4.EXC","CRate", "Structure", "Sample_Name") ##ADD DUMMY VARIABLE NAMES
  ARTPREDICT<-subset(PRED, FN.GP=="Arthropoda")    #FILTER PREDICT TO FN.GR
  ASCPREDICT<-subset(PRED, FN.GP=="Ascidea")       #FILTER PREDICT TO FN.GR
  BRYPREDICT<-subset(PRED, FN.GP=="Bryozoa")       #FILTER PREDICT TO FN.GR
  BIVPREDICT<-subset(PRED, FN.GP=="Bivalvia")      #FILTER PREDICT TO FN.GR
  CIRPREDICT<-subset(PRED, FN.GP=="Cirripedia")    #FILTER PREDICT TO FN.GR
  CNIPREDICT<-subset(PRED, FN.GP=="Cnidaria")      #FILTER PREDICT TO FN.GR
  DEMPREDICT<-subset(PRED, FN.GP=="Demospongae")   #FILTER PREDICT TO FN.GR
  ECHPREDICT<-subset(PRED, FN.GP=="Echinodermata") #FILTER PREDICT TO FN.GR
  GASPREDICT<-subset(PRED, FN.GP=="Gastropoda")    #FILTER PREDICT TO FN.GR
  PISPREDICT<-subset(PRED, FN.GP=="Pisces")        #FILTER PREDICT TO FN.GR
  POLPREDICT<-subset(PRED, FN.GP=="Polychaeta")    #FILTER PREDICT TO FN.GR
  MACROPRED1<-subset(PRED, Type=="Macroalgae")     #FILTER PREDICT TO FN.GR
  FFPREDICT1<-subset(PRED, IncludeClr=="1")        #FILTER PREDICT TO FN.GR
  AMEXPREDICT1<-subset(PRED, IncludeAmmex=="1")    #FILTER PREDICT TO FN.GR
  ARTPREDICT2<-rbind(ARTPREDICT, ARTADD1) #COMBINE FOR PREDICTIONS
  ASCPREDICT2<-rbind(ASCPREDICT, ASCADD1) #COMBINE FOR PREDICTIONS
  BRYPREDICT2<-rbind(BRYPREDICT, BRYADD1) #COMBINE FOR PREDICTIONS
  BIVPREDICT2<-rbind(BIVPREDICT, BIVADD1) #COMBINE FOR PREDICTIONS
  CIRPREDICT2<-rbind(CIRPREDICT, CIRADD1) #COMBINE FOR PREDICTIONS
  CNIPREDICT2<-rbind(CNIPREDICT, CNIADD1) #COMBINE FOR PREDICTIONS
  DEMPREDICT2<-rbind(DEMPREDICT, DEMADD1) #COMBINE FOR PREDICTIONS
  ECHPREDICT2<-rbind(ECHPREDICT, ECHADD1) #COMBINE FOR PREDICTIONS
  GASPREDICT2<-rbind(GASPREDICT, GASADD1) #COMBINE FOR PREDICTIONS
  PISPREDICT2<-rbind(PISPREDICT, PISADD1) #COMBINE FOR PREDICTIONS
  POLPREDICT2<-rbind(POLPREDICT, POLADD1) #COMBINE FOR PREDICTIONS
  MACPREDICT2<-rbind(MACROPRED1, MACADD1) #COMBINE FOR PREDICTIONS
  FFPREDICT2<-rbind(FFPREDICT1, BIVADD1)  #COMBINE FOR PREDICTIONS
  AMEXPREDICT2<-rbind(AMEXPREDICT1, BIVADD1)  #COMBINE FOR PREDICTIONS
  ALL<-rbind(AMEXPREDICT1, MACROPRED1)        #All species, for community metrics

  ##############################################################
  ####                  Respiration Rate                    ####
  ##############################################################

  ARTRESPP1<-predict(ARTRESPM1, ARTPREDICT2, interval = 'confidence') ## GOOD FIT
  ASCRESPP1<-predict(ASCRESPM1, ASCPREDICT2, interval = 'confidence') #GOOD FIT
  BRYRESPP1<-predict(BRYRESPM1, BRYPREDICT2, interval = 'confidence') ##POOR FIT, lack of data
  BIVRESPP1<-predict(BIVRESPM1, BIVPREDICT2, interval = 'confidence') #GOOD FIT
  CIRRESPP1<-predict(CIRRESPM1, CIRPREDICT2, interval = 'confidence') #GOOD FIT
  CNIRESPP1<-predict(CNIRESPM1, CNIPREDICT2, interval = 'confidence') #GOOD FIT
  DEMRESPP1<-predict(DEMRESPM1, DEMPREDICT2, interval = 'confidence') #GOOD FIT
  ECHRESPP1<-predict(ECHRESPM1, ECHPREDICT2, interval = 'confidence') #GOOD FIT
  GASRESPP1<-predict(GASRESPM1, GASPREDICT2, interval = 'confidence') #GOOD FIT
  PISRESPP1<-predict(PISRESPM1, PISPREDICT2, interval = 'confidence') ##OK FIT
  POLRESPP1<-predict(POLRESPM1, POLPREDICT2, interval = 'confidence') #GOOD FIT

  ARTRESPP1<-as.data.frame(ARTRESPP1) # COERCE TO DF
  ASCRESPP1<-as.data.frame(ASCRESPP1) # COERCE TO DF
  BRYRESPP1<-as.data.frame(BRYRESPP1) # COERCE TO DF
  BIVRESPP1<-as.data.frame(BIVRESPP1) # COERCE TO DF
  CIRRESPP1<-as.data.frame(CIRRESPP1) # COERCE TO DF
  CNIRESPP1<-as.data.frame(CNIRESPP1) # COERCE TO DF
  DEMRESPP1<-as.data.frame(DEMRESPP1) # COERCE TO DF
  ECHRESPP1<-as.data.frame(ECHRESPP1) # COERCE TO DF
  GASRESPP1<-as.data.frame(GASRESPP1) # COERCE TO DF
  PISRESPP1<-as.data.frame(PISRESPP1) # COERCE TO DF
  POLRESPP1<-as.data.frame(POLRESPP1) # COERCE TO DF

  ARTRESPP1$fit<-(exp(ARTRESPP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1
  ASCRESPP1$fit<-(exp(ASCRESPP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1
  BRYRESPP1$fit<-(exp(BRYRESPP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1
  BIVRESPP1$fit<-(exp(BIVRESPP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1
  CIRRESPP1$fit<-(exp(CIRRESPP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1
  CNIRESPP1$fit<-(exp(CNIRESPP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1
  DEMRESPP1$fit<-(exp(DEMRESPP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1
  ECHRESPP1$fit<-(exp(ECHRESPP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1
  GASRESPP1$fit<-(exp(GASRESPP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1
  PISRESPP1$fit<-(exp(PISRESPP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1
  POLRESPP1$fit<-(exp(POLRESPP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1

  ARTRESPP1$fit2<-((ARTRESPP1$fit)*(ARTPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  ASCRESPP1$fit2<-((ASCRESPP1$fit)*(ASCPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  BRYRESPP1$fit2<-((BRYRESPP1$fit)*(BRYPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  BIVRESPP1$fit2<-((BIVRESPP1$fit)*(BIVPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  CIRRESPP1$fit2<-((CIRRESPP1$fit)*(CIRPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  CNIRESPP1$fit2<-((CNIRESPP1$fit)*(CNIPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  DEMRESPP1$fit2<-((DEMRESPP1$fit)*(DEMPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  ECHRESPP1$fit2<-((ECHRESPP1$fit)*(ECHPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  GASRESPP1$fit2<-((GASRESPP1$fit)*(GASPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  PISRESPP1$fit2<-((PISRESPP1$fit)*(PISPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  POLRESPP1$fit2<-((POLRESPP1$fit)*(POLPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS

  ARTRESPP1$lwr<-(exp(ARTRESPP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1
  ASCRESPP1$lwr<-(exp(ASCRESPP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1
  BRYRESPP1$lwr<-(exp(BRYRESPP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1
  BIVRESPP1$lwr<-(exp(BIVRESPP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1
  CIRRESPP1$lwr<-(exp(CIRRESPP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1
  CNIRESPP1$lwr<-(exp(CNIRESPP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1
  DEMRESPP1$lwr<-(exp(DEMRESPP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1
  ECHRESPP1$lwr<-(exp(ECHRESPP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1
  GASRESPP1$lwr<-(exp(GASRESPP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1
  PISRESPP1$lwr<-(exp(PISRESPP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1
  POLRESPP1$lwr<-(exp(POLRESPP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1

  ARTRESPP1$lwr2<-((ARTRESPP1$lwr)*(ARTPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  ASCRESPP1$lwr2<-((ASCRESPP1$lwr)*(ASCPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  BRYRESPP1$lwr2<-((BRYRESPP1$lwr)*(BRYPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  BIVRESPP1$lwr2<-((BIVRESPP1$lwr)*(BIVPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  CIRRESPP1$lwr2<-((CIRRESPP1$lwr)*(CIRPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  CNIRESPP1$lwr2<-((CNIRESPP1$lwr)*(CNIPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  DEMRESPP1$lwr2<-((DEMRESPP1$lwr)*(DEMPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  ECHRESPP1$lwr2<-((ECHRESPP1$lwr)*(ECHPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  GASRESPP1$lwr2<-((GASRESPP1$lwr)*(GASPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  PISRESPP1$lwr2<-((PISRESPP1$lwr)*(PISPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  POLRESPP1$lwr2<-((POLRESPP1$lwr)*(POLPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS

  ARTRESPP1$upr<-(exp(ARTRESPP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1
  ASCRESPP1$upr<-(exp(ASCRESPP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1
  BRYRESPP1$upr<-(exp(BRYRESPP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1
  BIVRESPP1$upr<-(exp(BIVRESPP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1
  CIRRESPP1$upr<-(exp(CIRRESPP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1
  CNIRESPP1$upr<-(exp(CNIRESPP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1
  DEMRESPP1$upr<-(exp(DEMRESPP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1
  ECHRESPP1$upr<-(exp(ECHRESPP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1
  GASRESPP1$upr<-(exp(GASRESPP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1
  PISRESPP1$upr<-(exp(PISRESPP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1
  POLRESPP1$upr<-(exp(POLRESPP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1

  ARTRESPP1$upr2<-((ARTRESPP1$upr)*(ARTPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  ASCRESPP1$upr2<-((ASCRESPP1$upr)*(ASCPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  BRYRESPP1$upr2<-((BRYRESPP1$upr)*(BRYPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  BIVRESPP1$upr2<-((BIVRESPP1$upr)*(BIVPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  CIRRESPP1$upr2<-((CIRRESPP1$upr)*(CIRPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  CNIRESPP1$upr2<-((CNIRESPP1$upr)*(CNIPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  DEMRESPP1$upr2<-((DEMRESPP1$upr)*(DEMPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  ECHRESPP1$upr2<-((ECHRESPP1$upr)*(ECHPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  GASRESPP1$upr2<-((GASRESPP1$upr)*(GASPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  PISRESPP1$upr2<-((PISRESPP1$upr)*(PISPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  POLRESPP1$upr2<-((POLRESPP1$upr)*(POLPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS

  ##############################################################
  ####                Primary Productivity                 ####
  ##############################################################

  MACPREDICT2$EKMED<-as.factor(MACPREDICT2$EKMED)
  MACPRODP1<-predict(MACROPRODM1,MACPREDICT2, interval = 'confidence')
  MACPRODP1<-as.data.frame(MACPRODP1) # COERCE TO DF
  MACPRODP1$fit<-(exp(MACPRODP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1
  MACPRODP1$upr<-(exp(MACPRODP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1
  MACPRODP1$lwr<-(exp(MACPRODP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1
  MACPRODP1$fit2<-((MACPRODP1$fit)*(MACPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  MACPRODP1$lwr2<-((MACPRODP1$lwr)*(MACPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  MACPRODP1$upr2<-((MACPRODP1$upr)*(MACPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS

  #####################################################################
  ####               Respiration rate  - MACROALGAE                ####
  #####################################################################

  MACRESPP1<-predict(MACRORESPM1,MACPREDICT2, interval = 'confidence')
  MACRESPP1<-as.data.frame(MACRESPP1) # COERCE TO DF
  MACRESPP1$fit<-(exp(MACRESPP1$fit)) # BACK TRANSFORM TO MG/HR-1/G-1
  MACRESPP1$upr<-(exp(MACRESPP1$upr)) # BACK TRANSFORM TO MG/HR-1/G-1
  MACRESPP1$lwr<-(exp(MACRESPP1$lwr)) # BACK TRANSFORM TO MG/HR-1/G-1
  MACRESPP1$fit2<-((MACRESPP1$fit)*(MACPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  MACRESPP1$lwr2<-((MACRESPP1$lwr)*(MACPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  MACRESPP1$upr2<-((MACRESPP1$upr)*(MACPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS

  #####################################################################
  ####             Nutrient Excretion Rate, Ammonium               ####
  #####################################################################

  AMEXP1<-predict(AMEXM1, AMEXPREDICT2, se.fit=TRUE)
  AMEXP1$upr <- AMEXP1$fit + (2 * AMEXP1$se.fit)
  AMEXP1$lwr <- AMEXP1$fit - (2 * AMEXP1$se.fit)
  AMEXP1<-as.data.frame(AMEXP1) # COERCE TO DF
  AMEXP1$fit<-(exp(AMEXP1$fit))
  AMEXP1$lwr<-(exp(AMEXP1$lwr)) # BACK TRANSFORM TO UMOL/HR-1/G-1
  AMEXP1$upr<-(exp(AMEXP1$upr)) # BACK TRANSFORM TO UMOL/HR-1/G-1
  AMEXP1$fit2<-((AMEXP1$fit)*(AMEXPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  AMEXP1$lwr2<-((AMEXP1$lwr)*(AMEXPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  AMEXP1$upr2<-((AMEXP1$upr)*(AMEXPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS

  ##############################################################
  ####             Nutrient Uptake, Nitrate                 ####
  ##############################################################

  NITUPPRED1<-predict(NITUPM1, MACPREDICT2, se.fit = TRUE)
  NITUPPRED1$upr <- NITUPPRED1$fit + (2 * NITUPPRED1$se.fit)
  NITUPPRED1$lwr <- NITUPPRED1$fit - (2 * NITUPPRED1$se.fit)
  NITUPPRED1<-as.data.frame(NITUPPRED1) # COERCE TO DF
  NITUPPRED1$fit<-(exp(NITUPPRED1$fit)) # BACK TRANSFORM TO UMOL/G-1/HR-1
  NITUPPRED1$lwr<-(exp(NITUPPRED1$lwr)) # BACK TRANSFORM TO UMOL/G-1/HR-1
  NITUPPRED1$upr<-(exp(NITUPPRED1$upr)) # BACK TRANSFORM TO UMOL/G-1/HR-1
  NITUPPRED1$fit2<-((NITUPPRED1$fit)*(MACPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  NITUPPRED1$lwr2<-((NITUPPRED1$lwr)*(MACPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  NITUPPRED1$upr2<-((NITUPPRED1$upr)*(MACPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS

  ##############################################################
  ####             Nutrient Uptake, Ammonium                ####
  ##############################################################

  AMUPPRED1<-predict(AMUPM1, MACPREDICT2,  se.fit = TRUE)
  AMUPPRED1$upr <- AMUPPRED1$fit + (2 * AMUPPRED1$se.fit)
  AMUPPRED1$lwr <- AMUPPRED1$fit - (2 * AMUPPRED1$se.fit)
  AMUPPRED1<-as.data.frame(AMUPPRED1) # COERCE TO DF
  AMUPPRED1$fit<-(exp(AMUPPRED1$fit)) # BACK TRANSFORM TO UMOL/G-1/HR-1
  AMUPPRED1$lwr<-(exp(AMUPPRED1$lwr)) # BACK TRANSFORM TO UMOL/G-1/HR-1
  AMUPPRED1$upr<-(exp(AMUPPRED1$upr)) # BACK TRANSFORM TO UMOL/G-1/HR-1
  AMUPPRED1$fit2<-((AMUPPRED1$fit)*(MACPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  AMUPPRED1$lwr2<-((AMUPPRED1$lwr)*(MACPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  AMUPPRED1$upr2<-((AMUPPRED1$upr)*(MACPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS

  ##############################################################
  ####                   Clearance Rate                     ####
  ##############################################################

  CLRAPRED1<-predict(CLRAM1,FFPREDICT2, se.fit = TRUE)
  CLRAPRED1$upr <- CLRAPRED1$fit + (2 * CLRAPRED1$se.fit)
  CLRAPRED1$lwr <- CLRAPRED1$fit - (2 * CLRAPRED1$se.fit)
  CLRAPRED1<-as.data.frame(CLRAPRED1) # COERCE TO DF
  CLRAPRED1$fit<-(exp(CLRAPRED1$fit)) # BACK TRANSFORM TO UMOL/G-1/HR-1
  CLRAPRED1$lwr<-(exp(CLRAPRED1$lwr)) # BACK TRANSFORM TO UMOL/G-1/HR-1
  CLRAPRED1$upr<-(exp(CLRAPRED1$upr)) # BACK TRANSFORM TO UMOL/G-1/HR-1
  CLRAPRED1$fit2<-((CLRAPRED1$fit)*(FFPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  CLRAPRED1$lwr2<-((CLRAPRED1$lwr)*(FFPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  CLRAPRED1$upr2<-((CLRAPRED1$upr)*(FFPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  CLRAPRED1$fit2<-((CLRAPRED1$fit)*(FFPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  CLRAPRED1$lwr2<-((CLRAPRED1$lwr)*(FFPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS
  CLRAPRED1$upr2<-((CLRAPRED1$upr)*(FFPREDICT2$COMBIOM)) # TO TOTAL COMMUNITY BIOMASS

  ##############################################################
  ####                  Output Summation                    ####
  ##############################################################

  ####  RESPIRATION ####
  TOTRESPFITART<-sum(ARTRESPP1$fit2)#RESPIRATION FITTED SUMS
  TOTRESPFITASC<-sum(ASCRESPP1$fit2)#RESPIRATION FITTED SUMS
  TOTRESPFITBRY<-sum(BRYRESPP1$fit2)#RESPIRATION FITTED SUMS
  TOTRESPFITBIV<-sum(BIVRESPP1$fit2)#RESPIRATION FITTED SUMS
  TOTRESPFITCIR<-sum(CIRRESPP1$fit2)#RESPIRATION FITTED SUMS
  TOTRESPFITCNI<-sum(CNIRESPP1$fit2)#RESPIRATION FITTED SUMS
  TOTRESPFITDEM<-sum(DEMRESPP1$fit2)#RESPIRATION FITTED SUMS
  TOTRESPFITECH<-sum(ECHRESPP1$fit2)#RESPIRATION FITTED SUMS
  TOTRESPFITGAS<-sum(GASRESPP1$fit2)#RESPIRATION FITTED SUMS
  TOTRESPFITPIS<-sum(PISRESPP1$fit2)#RESPIRATION FITTED SUMS
  TOTRESPFITPOL<-sum(POLRESPP1$fit2)#RESPIRATION FITTED SUMS
  TOTRESPFITMAC<-sum(MACRESPP1$fit2)#RESPIRATION FITTED SUMS

  TOTRESPUPRART<-sum(ARTRESPP1$upr2)#RESPIRATION 95% SUMS
  TOTRESPUPRASC<-sum(ASCRESPP1$upr2)#RESPIRATION 95% SUMS
  TOTRESPUPRBRY<-sum(BRYRESPP1$upr2)#RESPIRATION 95% SUMS
  TOTRESPUPRBIV<-sum(BIVRESPP1$upr2)#RESPIRATION 95% SUMS
  TOTRESPUPRCIR<-sum(CIRRESPP1$upr2)#RESPIRATION 95% SUMS
  TOTRESPUPRCNI<-sum(CNIRESPP1$upr2)#RESPIRATION 95% SUMS
  TOTRESPUPRDEM<-sum(DEMRESPP1$upr2)#RESPIRATION 95% SUMS
  TOTRESPUPRECH<-sum(ECHRESPP1$upr2)#RESPIRATION 95% SUMS
  TOTRESPUPRGAS<-sum(GASRESPP1$upr2)#RESPIRATION 95% SUMS
  TOTRESPUPRPIS<-sum(PISRESPP1$upr2)#RESPIRATION 95% SUMS
  TOTRESPUPRPOL<-sum(POLRESPP1$upr2)#RESPIRATION 95% SUMS
  TOTRESPUPRMAC<-sum(MACRESPP1$upr2)#RESPIRATION 95% SUMS

  TOTRESPLWRART<-sum(ARTRESPP1$lwr2)#RESPIRATION 5% SUMS
  TOTRESPLWRASC<-sum(ASCRESPP1$lwr2)#RESPIRATION 5% SUMS
  TOTRESPLWRBRY<-sum(BRYRESPP1$lwr2)#RESPIRATION 5% SUMS
  TOTRESPLWRBIV<-sum(BIVRESPP1$lwr2)#RESPIRATION 5% SUMS
  TOTRESPLWRCIR<-sum(CIRRESPP1$lwr2)#RESPIRATION 5% SUMS
  TOTRESPLWRCNI<-sum(CNIRESPP1$lwr2)#RESPIRATION 5% SUMS
  TOTRESPLWRDEM<-sum(DEMRESPP1$lwr2)#RESPIRATION 5% SUMS
  TOTRESPLWRECH<-sum(ECHRESPP1$lwr2)#RESPIRATION 5% SUMS
  TOTRESPLWRGAS<-sum(GASRESPP1$lwr2)#RESPIRATION 5% SUMS
  TOTRESPLWRPIS<-sum(PISRESPP1$lwr2)#RESPIRATION 5% SUMS
  TOTRESPLWRPOL<-sum(POLRESPP1$lwr2)#RESPIRATION 5% SUMS
  TOTRESPLWRMAC<-sum(MACRESPP1$lwr2)#RESPIRATION 5% SUMS

  TOTRESPFIT<-sum(TOTRESPFITART,TOTRESPFITASC,TOTRESPFITBRY,TOTRESPFITBIV,TOTRESPFITCIR,TOTRESPFITCNI,TOTRESPFITDEM,TOTRESPFITECH,TOTRESPFITGAS,TOTRESPFITPIS,TOTRESPFITPOL,TOTRESPFITMAC)
  TOTRESPLWR<-sum(TOTRESPLWRART,TOTRESPLWRASC,TOTRESPLWRBRY,TOTRESPLWRBIV,TOTRESPLWRCIR,TOTRESPLWRCNI,TOTRESPLWRDEM,TOTRESPLWRECH,TOTRESPLWRGAS,TOTRESPLWRPIS,TOTRESPLWRPOL,TOTRESPLWRMAC)
  TOTRESPUPR<-sum(TOTRESPUPRART,TOTRESPUPRASC,TOTRESPUPRBRY,TOTRESPUPRBIV,TOTRESPUPRCIR,TOTRESPUPRCNI,TOTRESPUPRDEM,TOTRESPUPRECH,TOTRESPUPRGAS,TOTRESPUPRPIS,TOTRESPUPRPOL,TOTRESPUPRMAC)

  ####   PRODUCTIVITY   ####

  TOTPRODFITAa<-sum(MACPRODP1$fit2)#RESPIRATION FITTED SUMS
  TOTPRODUPRAa<-sum(MACPRODP1$upr2)
  TOTPRODLWRAa<-sum(MACPRODP1$lwr2)

  ####   OXYGEN FLUX   ####

  OXYF<-TOTPRODFITAa-TOTRESPFIT
  OXYL<-TOTPRODLWRAa-TOTRESPLWR
  OXYH<-TOTPRODUPRAa-TOTRESPUPR

  #### AMMONIUM EXCRETION ####

  AMEXTOT<-sum(AMEXP1$fit2)
  AMEXTOTupr<-sum(AMEXP1$upr2)
  AMEXTOTlwr<-sum(AMEXP1$lwr2)

  #### AMMONIUM UPTAKE ####

  AMUPTOT<-sum(AMUPPRED1$fit2)
  AMUPTOTupr<-sum(AMUPPRED1$upr2)
  AMUPTOTlwr<-sum(AMUPPRED1$lwr2)

  #### AMMONIUM FLUX ####

  AMMF<-AMUPTOT-AMEXTOT
  AMMH<-AMUPTOTupr-AMEXTOTupr
  AMML<-AMUPTOTlwr-AMEXTOTlwr

  #### NITRATE UPTAKE ####

  NITTOT<-sum(NITUPPRED1$fit2)
  NITTOTupr<-sum(NITUPPRED1$upr2)
  NITTOTlwr<-sum(NITUPPRED1$lwr2)

  #### CLEARANCE RATE ####
  CLRTOT<-sum(CLRAPRED1$fit2)
  CLRTOTupr<-sum(CLRAPRED1$upr2)
  CLRTOTlwr<-sum(CLRAPRED1$lwr2)

  ##### BIOMASS ####

  BIOMANI<-sum(AMEXPREDICT1$COMBIOM)
  BIOMALG<-sum(MACROPRED1$COMBIOM)
  BIOMtot <- sum(BIOMANI+BIOMALG)

  ##############################################################
  ####                 Community Metrics                    ####
  ##############################################################

  SDIV<-vegan::diversity(ALL$COMBIOM, index = "shannon", MARGIN = 1, base = exp(1))
  SRICH<-vegan::specnumber(ALL$COMBIOM, MARGIN = 1)
  SEVE<- SDIV/log(SRICH)

  ##############################################################
  ####                 ELO Aesthetic score                  ####
  ##############################################################

  ELOPRED<- data.frame(Sp.Rich=numeric(1),S.EVE=numeric(1), Structure=numeric(1))
  ELOPRED$Sp.Rich<-SRICH
  ELOPRED$S.EVE<-SEVE
  ELOPRED$Structure<-mean(PRED$Structure)
  ELOval<-as.data.frame(ELOval<-(ifelse(ELOPRED$Structure>0,(predict(ELOSTR,ELOPRED, interval='confidence', se.fit=TRUE)),0)))
  colnames(ELOval)[1] <- "fit"
  ELOval["upr"[!("upr" %in% colnames(ELOval))]] = 0
  ELOval["lwr"[!("lwr" %in% colnames(ELOval))]] = 0
  ELOval2<- exp(ELOval)

  ##############################################################
  ####                    Output to XLSX                    ####
  ##############################################################

  OutputEST<-data.frame(c(OXYF,TOTRESPFIT,TOTPRODFITAa,AMMF,AMEXTOT,AMUPTOT,NITTOT,CLRTOT,BIOMALG,BIOMANI,ELOval2$fit,SRICH,SDIV,SEVE))
  Outputlwr<-data.frame(c(OXYL,TOTRESPLWR,TOTPRODLWRAa,AMML,AMEXTOTlwr,AMUPTOTlwr,NITTOTlwr,CLRTOTlwr,0,0,ELOval2$lwr,SRICH,SDIV,SEVE))
  Outputupr<-data.frame(c(OXYH,TOTRESPUPR,TOTPRODUPRAa,AMMH,AMEXTOTupr,AMUPTOTupr,NITTOTupr,CLRTOTupr,0,0,ELOval2$upr,SRICH,SDIV,SEVE))


  Outputbook <- openxlsx::loadWorkbook("Outputs.xlsx")
  openxlsx::writeData(Outputbook,"DataIN",OutputEST,startRow=2,startCol=2, colNames = FALSE)
  openxlsx::writeData(Outputbook,"DataIN",Outputupr,startRow=2,startCol=3, colNames = FALSE)
  openxlsx::writeData(Outputbook,"DataIN",Outputlwr,startRow=2,startCol=4, colNames = FALSE)
  openxlsx::saveWorkbook(Outputbook,file = output)


}
